.. default-role:: literal

ChangeLog
=========

Changes from 0.2 to 0.2.1 (Oct 19, 2024)
----------------------------------------

* Various bug fixes and enhancements.

* Don't generate JupyterLite version of the guide.  The normal Jupyter
  notebook version is still available.

Changes from 0.0.1 to 0.2 (Jan 9, 2024)
---------------------------------------

* Removed unbounded boxes and replaced them with unbounded throttles.

* Added support for custom game configuration and mods.

* Added Jupyter notebook version of the guide.

* Removed all dependencies except Python itself.

* Numerious other changes.

Version 0.0.1 (Jan 21, 2023)
----------------------------

* Initial Release
